@@ -1,5 +1,5 @@
 package Tickit::Widget::Layout::Desktop::Window;
-$Tickit::Widget::Layout::Desktop::Window::VERSION = '0.006';
+$Tickit::Widget::Layout::Desktop::Window::VERSION = '0.007';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Tickit::Widget::Layout::Desktop - provides a holder for "desktop-like" widget be
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =cut
 
@@ -20,7 +20,6 @@ use Tickit::RenderBuffer qw(LINE_THICK LINE_SINGLE LINE_DOUBLE);
 use Tickit::Utils qw(textwidth);
 use Tickit::Style;
 
-use constant HAVE_RT98211_BUG => (Tickit::RenderBuffer->VERSION <= 0.46);
 use constant WIDGET_PEN_FROM_STYLE => 1;
 
 BEGIN {
@@ -98,7 +97,6 @@ sub action_close {
 	my ($self) = @_;
 	# Close button... probably need some way to indicate when
 	# this happens, Tickit::Window doesn't appear to have set_on_closed ?
-	$self->window->clear;
 	$self->window->close;
 }
 
@@ -270,44 +268,22 @@ sub render_to_rb {
 	# our overlay, all being well.
 	$rb->linebox_at(0, $h, 0, $w, $line);
 
-	if(0 && $self->get_style_values('linetype') eq 'round') {
-		# ->get_cell is absolute (Tickit 0.46), so we need to apply an origin offset
-		# to look up our cells
-		my $origin = [0,0];
+	if($self->get_style_values('linetype') eq 'round') {
 		my $limit = [
 			$win->root->bottom,
 			$win->root->right
 		];
-		if(HAVE_RT98211_BUG) {
-			{ # not beautiful, but it's going away
-				my $ww = $win;
-				do {
-					$origin->[0] += $ww->rect->top;
-					$origin->[1] += $ww->rect->left;
-					$ww = $ww->parent;
-				} while $ww;
-			}
-		}
 
 		my @corner_char;
 		CORNER:
 		foreach my $corner ([0,0], [0,$w], [$h,0], [$h,$w]) {
 			my ($y, $x) = @$corner;
-			my $abs_y = $y + $origin->[0];
-			my $abs_x = $x + $origin->[1];
-			next CORNER if $abs_y >= $limit->[0] or $abs_x >= $limit->[1] or $abs_x < 0 or $abs_y < 0;
+			next CORNER if $y >= $limit->[0] or $x >= $limit->[1] or $x < 0 or $y < 0;
 
 			# Apply our window offset... note that ->get_cell will segfault if
 			# we're outside the render area, so the widget width had better be
 			# correct here.
-			$abs_y -= $win->abs_top;
-			#$abs_x -= $win->abs_left;
-			warn "will getcell for $abs_y, $abs_x with " . $win->lines . ", " . $win->cols . " and offset " . $win->abs_top . "\n";
-			my $cell = eval { $rb->get_cell($abs_y, $abs_x); } // do {
-
-				die $@;
-			};
-			warn "success - cell $cell, @$cell\n";
+			my $cell = eval { $rb->get_cell($y, $x); };
 
 			# If we have a line segment here, ->linemask should be an object...
 			next CORNER unless $cell and my $linemask = $cell->linemask;
@@ -424,27 +400,26 @@ sub reshape {
 }
 
 sub set_child_window {
-   my $self = shift;
+	my $self = shift;
 
-   my $window = $self->window or return;
-   my $child  = $self->child  or return;
+	my $window = $self->window or return;
+	my $child  = $self->child  or return;
 
-   my $lines = $window->lines;
-   my $cols  = $window->cols;
+	my $lines = $window->lines;
+	my $cols  = $window->cols;
 
-   if( $lines > 2 and $cols > 2 ) {
-      if( my $childwin = $child->window ) {
-         $childwin->change_geometry( 1, 1, $lines - 2, $cols - 2 );
-      }
-      else {
-         my $childwin = $window->make_sub( 1, 1, $lines - 2, $cols - 2 );
-         $child->set_window( $childwin );
-      }
-   } else {
-      if( $child->window ) {
-         $child->set_window( undef );
-      }
-   }
+	if( $lines > 2 and $cols > 2 ) {
+		if( my $childwin = $child->window ) {
+			$childwin->change_geometry( 1, 1, $lines - 2, $cols - 2 );
+		} else {
+			my $childwin = $window->make_sub( 1, 1, $lines - 2, $cols - 2 );
+			$child->set_window( $childwin );
+		}
+	} else {
+		if( $child->window ) {
+			$child->set_window( undef );
+		}
+	}
 }
 
 sub mark_active {
